@@ -34,12 +34,14 @@ import qualified Data.Set as S
 import qualified Data.Map as M
 import Data.Function
 import Data.Char
+import Data.ByteString.Builder
 import Control.Concurrent (threadDelay)
 
 import Annex.Common
 import Annex.BranchState
 import Annex.Journal
 import Annex.GitOverlay
+import Annex.Tmp
 import qualified Git
 import qualified Git.Command
 import qualified Git.Ref
@@ -65,7 +67,6 @@ import qualified Annex.Queue
 import Annex.Branch.Transitions
 import qualified Annex
 import Annex.Hook
-import Utility.FileSystemEncoding
 import Utility.Directory.Stream
 
 {- Name of the branch that is used to store git-annex's information. -}
@@ -210,7 +211,7 @@ updateTo' pairs = do
  - content is returned.
  -
  - Returns an empty string if the file doesn't exist yet. -}
-get :: FilePath -> Annex String
+get :: FilePath -> Annex L.ByteString
 get file = do
 	update
 	getLocal file
@@ -219,21 +220,21 @@ get file = do
  - reflect changes in remotes.
  - (Changing the value this returns, and then merging is always the
  - same as using get, and then changing its value.) -}
-getLocal :: FilePath -> Annex String
+getLocal :: FilePath -> Annex L.ByteString
 getLocal file = go =<< getJournalFileStale file
   where
 	go (Just journalcontent) = return journalcontent
 	go Nothing = getRef fullname file
 
 {- Gets the content of a file as staged in the branch's index. -}
-getStaged :: FilePath -> Annex String
+getStaged :: FilePath -> Annex L.ByteString
 getStaged = getRef indexref
   where
 	-- This makes git cat-file be run with ":file",
 	-- so it looks at the index.
 	indexref = Ref ""
 
-getHistorical :: RefDate -> FilePath -> Annex String
+getHistorical :: RefDate -> FilePath -> Annex L.ByteString
 getHistorical date file =
 	-- This check avoids some ugly error messages when the reflog
 	-- is empty.
@@ -242,27 +243,29 @@ getHistorical date file =
 		, getRef (Git.Ref.dateRef fullname date) file
 		)
 
-getRef :: Ref -> FilePath -> Annex String
-getRef ref file = withIndex $ decodeBS <$> catFile ref file
+getRef :: Ref -> FilePath -> Annex L.ByteString
+getRef ref file = withIndex $ catFile ref file
 
 {- Applies a function to modify the content of a file.
  -
  - Note that this does not cause the branch to be merged, it only
  - modifes the current content of the file on the branch.
  -}
-change :: FilePath -> (String -> String) -> Annex ()
+change :: Journalable content => FilePath -> (L.ByteString -> content) -> Annex ()
 change file f = lockJournal $ \jl -> f <$> getLocal file >>= set jl file
 
 {- Applies a function which can modify the content of a file, or not. -}
-maybeChange :: FilePath -> (String -> Maybe String) -> Annex ()
+maybeChange :: Journalable content => FilePath -> (L.ByteString -> Maybe content) -> Annex ()
 maybeChange file f = lockJournal $ \jl -> do
 	v <- getLocal file
 	case f v of
-		Just v' | v' /= v -> set jl file v'
+		Just jv ->
+			let b = journalableByteString jv
+			in when (v /= b) $ set jl file b
 		_ -> noop
 
 {- Records new content of a file into the journal -}
-set :: JournalLocked -> FilePath -> String -> Annex ()
+set :: Journalable content => JournalLocked -> FilePath -> content -> Annex ()
 set = setJournalFile
 
 {- Commit message used when making a commit of whatever data has changed
@@ -320,7 +323,7 @@ commitIndex' jl branchref message basemessage retrynum parents = do
   where
 	-- look for "parent ref" lines and return the refs
 	commitparents = map (Git.Ref . snd) . filter isparent .
-		map (toassoc . decodeBS) . L.split newline
+		map (toassoc . decodeBL) . L.split newline
 	newline = fromIntegral (ord '\n')
 	toassoc = separate (== ' ')
 	isparent (k,_) = k == "parent"
@@ -486,9 +489,7 @@ stageJournal jl = withIndex $ do
 		mapM_ (removeFile . (dir </>)) stagedfs
 		hClose jlogh
 		nukeFile jlogf
-	openjlog = do
-		tmpdir <- fromRepo gitAnnexTmpMiscDir
-		createAnnexDirectory tmpdir
+	openjlog = withOtherTmp $ \tmpdir -> 
 		liftIO $ openTempFile tmpdir "jlog"
 
 {- This is run after the refs have been merged into the index,
@@ -522,7 +523,7 @@ handleTransitions jl localts refs = do
 			return True
   where
 	getreftransition ref = do
-		ts <- parseTransitionsStrictly "remote" . decodeBS
+		ts <- parseTransitionsStrictly "remote"
 			<$> catFile ref transitionsLog
 		return (ref, ts)
 
@@ -558,7 +559,7 @@ performTransitionsLocked jl ts neednewlocalbranch transitionedrefs = do
 		| neednewlocalbranch && null transitionedrefs = "new branch for transition " ++ tdesc
 		| otherwise = "continuing transition " ++ tdesc
 	tdesc = show $ map describeTransition tlist
-	tlist = transitionList ts
+	tlist = knownTransitionList ts
 
 	{- The changes to make to the branch are calculated and applied to
 	 - the branch directly, rather than going through the journal,
@@ -585,7 +586,8 @@ performTransitionsLocked jl ts neednewlocalbranch transitionedrefs = do
 				-- File is deleted; can't run any other
 				-- transitions on it.
 				return ()
-			ChangeFile content' -> do
+			ChangeFile builder -> do
+				let content' = toLazyByteString builder
 				sha <- hashBlob content'
 				Annex.Queue.addUpdateIndex $ Git.UpdateIndex.pureStreamer $
 					Git.UpdateIndex.updateIndexLine sha TreeFile (asTopFilePath file)
@@ -595,7 +597,7 @@ performTransitionsLocked jl ts neednewlocalbranch transitionedrefs = do
 
 checkBranchDifferences :: Git.Ref -> Annex ()
 checkBranchDifferences ref = do
-	theirdiffs <- allDifferences . parseDifferencesLog . decodeBS
+	theirdiffs <- allDifferences . parseDifferencesLog
 		<$> catFile ref differenceLog
 	mydiffs <- annexDifferences <$> Annex.getGitConfig
 	when (theirdiffs /= mydiffs) $
