@@ -38,7 +38,6 @@ import qualified Git.Ref
 import Annex.Link
 import Annex.CurrentBranch
 import Types.AdjustedBranch
-import Utility.FileSystemEncoding
 
 catFile :: Git.Branch -> FilePath -> Annex L.ByteString
 catFile branch file = do
@@ -106,12 +105,12 @@ catKey ref = go =<< catObjectMetaData ref
 		-- Avoid catting large files, that cannot be symlinks or
 		-- pointer files, which would require buffering their
 		-- content in memory, as well as a lot of IO.
-		| sz <= maxPointerSz = parseLinkOrPointer <$> catObject ref
+		| sz <= maxPointerSz = parseLinkTargetOrPointer . L.toStrict <$> catObject ref
 	go _ = return Nothing
 
 {- Gets a symlink target. -}
 catSymLinkTarget :: Sha -> Annex String
-catSymLinkTarget sha = fromInternalGitPath . decodeBS <$> get
+catSymLinkTarget sha = fromInternalGitPath . decodeBL <$> get
   where
 	-- Avoid buffering the whole file content, which might be large.
 	-- 8192 is enough if it really is a symlink.
