@@ -405,7 +405,7 @@ warnUnverifiableInsecure k = warning $ unwords
 	, "this safety check.)"
 	]
   where
-	kv = formatKeyVariety (keyVariety k)
+	kv = decodeBS (formatKeyVariety (keyVariety k))
 
 data VerifyConfig = AlwaysVerify | NoVerify | RemoteVerify Remote | DefaultVerify
 
@@ -544,7 +544,7 @@ checkSecureHashes key
 	| cryptographicallySecure (keyVariety key) = return True
 	| otherwise = ifM (annexSecureHashesOnly <$> Annex.getGitConfig)
 		( do
-			warning $ "annex.securehashesonly blocked adding " ++ formatKeyVariety (keyVariety key) ++ " key to annex objects"
+			warning $ "annex.securehashesonly blocked adding " ++ decodeBS (formatKeyVariety (keyVariety key)) ++ " key to annex objects"
 			return False
 		, return True
 		)
@@ -880,7 +880,8 @@ saveState nocommit = doSideAction $ do
 		whenM (annexAlwaysCommit <$> Annex.getGitConfig) $
 			Annex.Branch.commit =<< Annex.Branch.commitMessage
 
-{- Downloads content from any of a list of urls. -}
+{- Downloads content from any of a list of urls, displaying a progress
+ - meter. -}
 downloadUrl :: Key -> MeterUpdate -> [Url.URLString] -> FilePath -> Annex Bool
 downloadUrl k p urls file = 
 	-- Poll the file to handle configurations where an external
