@@ -1,13 +1,17 @@
 {- git-annex file locations
  -
- - Copyright 2010-2017 Joey Hess <id@joeyh.name>
+ - Copyright 2010-2019 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
+{-# LANGUAGE OverloadedStrings #-}
+
 module Annex.Locations (
 	keyFile,
+	keyFile',
 	fileKey,
+	fileKey',
 	keyPaths,
 	keyPath,
 	annexDir,
@@ -24,7 +28,9 @@ module Annex.Locations (
 	annexLocations,
 	gitAnnexDir,
 	gitAnnexObjectDir,
-	gitAnnexTmpMiscDir,
+	gitAnnexTmpOtherDir,
+	gitAnnexTmpOtherLock,
+	gitAnnexTmpOtherDirOld,
 	gitAnnexTmpObjectDir,
 	gitAnnexTmpObjectLocation,
 	gitAnnexTmpWorkDir,
@@ -76,16 +82,15 @@ module Annex.Locations (
 	hashDirLower,
 	preSanitizeKeyName,
 	reSanitizeKeyName,
-
-	prop_isomorphic_fileKey
 ) where
 
 import Data.Char
 import Data.Default
+import qualified Data.ByteString.Char8 as S8
+import qualified Data.ByteString.Lazy as L
 
 import Common
 import Key
-import Types.Key
 import Types.UUID
 import Types.GitConfig
 import Types.Difference
@@ -243,14 +248,22 @@ gitAnnexDir r = addTrailingPathSeparator $ Git.localGitDir r </> annexDir
 gitAnnexObjectDir :: Git.Repo -> FilePath
 gitAnnexObjectDir r = addTrailingPathSeparator $ Git.localGitDir r </> objectDir
 
-{- .git/annex/misctmp/ is used for random temp files -}
-gitAnnexTmpMiscDir :: Git.Repo -> FilePath
-gitAnnexTmpMiscDir r = addTrailingPathSeparator $ gitAnnexDir r </> "misctmp"
-
 {- .git/annex/tmp/ is used for temp files for key's contents -}
 gitAnnexTmpObjectDir :: Git.Repo -> FilePath
 gitAnnexTmpObjectDir r = addTrailingPathSeparator $ gitAnnexDir r </> "tmp"
 
+{- .git/annex/othertmp/ is used for other temp files -}
+gitAnnexTmpOtherDir :: Git.Repo -> FilePath
+gitAnnexTmpOtherDir r = addTrailingPathSeparator $ gitAnnexDir r </> "othertmp"
+
+{- Lock file for gitAnnexTmpOtherDir. -}
+gitAnnexTmpOtherLock :: Git.Repo -> FilePath
+gitAnnexTmpOtherLock r = gitAnnexDir r </> "othertmp.lck"
+
+{- Directory used by old versions of git-annex. -}
+gitAnnexTmpOtherDirOld :: Git.Repo -> FilePath
+gitAnnexTmpOtherDirOld r = addTrailingPathSeparator $ gitAnnexDir r </> "misctmp"
+
 {- The temp file to use for a given key's content. -}
 gitAnnexTmpObjectLocation :: Key -> Git.Repo -> FilePath
 gitAnnexTmpObjectLocation key r = gitAnnexTmpObjectDir r </> keyFile key
@@ -479,8 +492,8 @@ preSanitizeKeyName' resanitize = concatMap escape
   where
 	escape c
 		| isAsciiUpper c || isAsciiLower c || isDigit c = [c]
-		| c `elem` ".-_" = [c] -- common, assumed safe
-		| c `elem` "/%:" = [c] -- handled by keyFile
+		| c `elem` ['.', '-', '_'] = [c] -- common, assumed safe
+		| c `elem` ['/', '%', ':'] = [c] -- handled by keyFile
 		-- , is safe and uncommon, so will be used to escape
 		-- other characters. By itself, it is escaped to 
 		-- doubled form.
@@ -509,33 +522,38 @@ reSanitizeKeyName = preSanitizeKeyName' True
  - can cause existing objects to get lost.
  -}
 keyFile :: Key -> FilePath
-keyFile = concatMap esc . key2file
+keyFile = fromRawFilePath . keyFile'
+
+keyFile' :: Key -> RawFilePath
+keyFile' k = 
+	let b = L.toStrict (serializeKey' k)
+	in if any (`S8.elem` b) ['&', '%', ':', '/']
+		then S8.concatMap esc b
+		else b
   where
 	esc '&' = "&a"
 	esc '%' = "&s"
 	esc ':' = "&c"
 	esc '/' = "%"
-	esc c = [c]
+	esc c = S8.singleton c
 
 {- Reverses keyFile, converting a filename fragment (ie, the basename of
  - the symlink target) into a key. -}
 fileKey :: FilePath -> Maybe Key
-fileKey = file2key . unesc [] 
-  where
-	unesc r [] = reverse r
-	unesc r ('%':cs) = unesc ('/':r) cs
-	unesc r ('&':'c':cs) = unesc (':':r) cs
-	unesc r ('&':'s':cs) = unesc ('%':r) cs
-	unesc r ('&':'a':cs) = unesc ('&':r) cs
-	unesc r (c:cs) = unesc (c:r) cs
+fileKey = fileKey' . toRawFilePath
 
-{- for quickcheck -}
-prop_isomorphic_fileKey :: String -> Bool
-prop_isomorphic_fileKey s
-	| null s = True -- it's not legal for a key to have no keyName
-	| otherwise= Just k == fileKey (keyFile k)
+fileKey' :: RawFilePath -> Maybe Key
+fileKey' = deserializeKey' . S8.intercalate "/" . map go . S8.split '%'
   where
-	k = stubKey { keyName = s, keyVariety = OtherKey "test" }
+	go = S8.concat . unescafterfirst . S8.split '&'
+	unescafterfirst [] = []
+	unescafterfirst (b:bs) = b : map (unesc . S8.uncons) bs
+	unesc :: Maybe (Char, S8.ByteString) -> S8.ByteString
+	unesc Nothing = mempty
+	unesc (Just ('c', b)) = S8.cons ':' b
+	unesc (Just ('s', b)) = S8.cons '%' b
+	unesc (Just ('a', b)) = S8.cons '&' b
+	unesc (Just (c, b)) = S8.cons c b
 
 {- A location to store a key on a special remote that uses a filesystem.
  - A directory hash is used, to protect against filesystems that dislike
