@@ -8,9 +8,10 @@
 module Annex.VariantFile where
 
 import Annex.Common
-import Utility.FileSystemEncoding
 import Utility.Hash
 
+import qualified Data.ByteString.Lazy as L
+
 variantMarker :: String
 variantMarker = ".variant-"
 
@@ -35,10 +36,10 @@ mkVariant file variant = takeDirectory file
  -}
 variantFile :: FilePath -> Key -> FilePath
 variantFile file key
-	| doubleconflict = mkVariant file (key2file key)
-	| otherwise = mkVariant file (shortHash $ key2file key)
+	| doubleconflict = mkVariant file (keyFile key)
+	| otherwise = mkVariant file (shortHash $ serializeKey' key)
   where
 	doubleconflict = variantMarker `isInfixOf` file
 
-shortHash :: String -> String
-shortHash = take 4 . show . md5 . encodeBS
+shortHash :: L.ByteString -> String
+shortHash = take 4 . show . md5
