@@ -3,7 +3,7 @@
  - We don't have a way yet to keep true distributed vector clocks.
  - The next best thing is a timestamp.
  -
- - Copyright 2017 Joey Hess <id@joeyh.name>
+ - Copyright 2017-2019 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -11,17 +11,19 @@
 module Annex.VectorClock where
 
 import Data.Time.Clock.POSIX
+import Data.ByteString.Builder
 import Control.Applicative
 import Prelude
 
 import Utility.Env
 import Utility.TimeStamp
 import Utility.QuickCheck
+import qualified Data.Attoparsec.ByteString.Lazy as A
 
 -- | Some very old logs did not have any time stamp at all;
 -- Unknown is used for those.
 data VectorClock = Unknown | VectorClock POSIXTime
-	deriving (Eq, Ord)
+	deriving (Eq, Ord, Show)
 
 -- Unknown is oldest.
 prop_VectorClock_sane :: Bool
@@ -39,8 +41,14 @@ currentVectorClock = go =<< getEnv "GIT_ANNEX_VECTOR_CLOCK"
 		Nothing -> VectorClock <$> getPOSIXTime
 
 formatVectorClock :: VectorClock -> String
-formatVectorClock  Unknown = "0"
+formatVectorClock Unknown = "0"
 formatVectorClock (VectorClock t) = show t
 
+buildVectorClock :: VectorClock -> Builder
+buildVectorClock = string7 . formatVectorClock
+
 parseVectorClock :: String -> Maybe VectorClock
 parseVectorClock t = VectorClock <$> parsePOSIXTime t
+
+vectorClockParser :: A.Parser VectorClock
+vectorClockParser = VectorClock <$> parserPOSIXTime
