@@ -45,6 +45,7 @@ import Assistant.Ssh
 import Config
 import Config.GitConfig
 import Config.DynamicConfig
+import Types.Group
 
 import qualified Data.Text as T
 import qualified Data.Map as M
@@ -66,15 +67,15 @@ getRepoConfig :: UUID -> Maybe Remote -> Annex RepoConfig
 getRepoConfig uuid mremote = do
 	-- Ensure we're editing current data by discarding caches.
 	void groupMapLoad
-	void uuidMapLoad
+	void uuidDescMapLoad
 
 	groups <- lookupGroups uuid
 	remoteconfig <- M.lookup uuid <$> readRemoteLog
 	let (repogroup, associateddirectory) = case getStandardGroup groups of
-		Nothing -> (RepoGroupCustom $ unwords $ S.toList groups, Nothing)
+		Nothing -> (RepoGroupCustom $ unwords $ map fromGroup $ S.toList groups, Nothing)
 		Just g -> (RepoGroupStandard g, associatedDirectory remoteconfig g)
 	
-	description <- fmap T.pack . M.lookup uuid <$> uuidMap
+	description <- fmap (T.pack . fromUUIDDesc) . M.lookup uuid <$> uuidDescMap
 
 	syncable <- case mremote of
 		Just r -> liftIO $ getDynamicConfig $ remoteAnnexSync $ Remote.gitconfig r
@@ -90,8 +91,8 @@ getRepoConfig uuid mremote = do
 setRepoConfig :: UUID -> Maybe Remote -> RepoConfig -> RepoConfig -> Handler ()
 setRepoConfig uuid mremote oldc newc = do
 	when descriptionChanged $ liftAnnex $ do
-		maybe noop (describeUUID uuid . T.unpack) (repoDescription newc)
-		void uuidMapLoad
+		maybe noop (describeUUID uuid . toUUIDDesc . T.unpack) (repoDescription newc)
+		void uuidDescMapLoad
 	when nameChanged $ do
 		liftAnnex $ do
 			name <- uniqueRemoteName (legalName newc) 0 <$> Annex.getGitRemotes
@@ -127,7 +128,7 @@ setRepoConfig uuid mremote oldc newc = do
 	when groupChanged $ do
 		liftAnnex $ case repoGroup newc of
 			RepoGroupStandard g -> setStandardGroup uuid g
-			RepoGroupCustom s -> groupSet uuid $ S.fromList $ words s
+			RepoGroupCustom s -> groupSet uuid $ S.fromList $ map toGroup $ words s
 		{- Enabling syncing will cause a scan,
 		 - so avoid queueing a duplicate scan. -}
 		when (repoSyncable newc && not syncableChanged) $ liftAssistant $
