@@ -44,7 +44,7 @@ transfersDisplay = do
 	isrunning info = not $
 		transferPaused info || isNothing (startedTime info)
 	desc transfer info = case associatedFile info of
-		AssociatedFile Nothing -> key2file $ transferKey transfer
+		AssociatedFile Nothing -> serializeKey $ transferKey transfer
 		AssociatedFile (Just af) -> af
 
 {- Simplifies a list of transfers, avoiding display of redundant
