@@ -5,8 +5,6 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
-{-# LANGUAGE CPP #-}
-
 module Main where
 
 import System.Environment
@@ -36,7 +34,6 @@ main = getArgs >>= go
 mklibs :: FilePath -> IO ()
 mklibs top = do
 	fs <- dirContentsRecursive top
-	mapM_ symToHardLink fs
 	exes <- filterM checkExe fs
 	libs <- parseLdd <$> readProcess "ldd" exes
 	glibclibs <- glibcLibs
@@ -65,7 +62,17 @@ installLinkerShim :: FilePath -> FilePath -> FilePath -> IO ()
 installLinkerShim top linker exe = do
 	createDirectoryIfMissing True (top </> shimdir)
 	createDirectoryIfMissing True (top </> exedir)
-	renameFile exe exedest
+	ifM (isSymbolicLink <$> getSymbolicLinkStatus exe)
+		( do
+			sl <- readSymbolicLink exe
+			nukeFile exe
+			nukeFile exedest
+			-- Assume that for a symlink, the destination
+			-- will also be shimmed.
+			let sl' = ".." </> takeFileName sl </> takeFileName sl
+			createSymbolicLink sl' exedest
+		, renameFile exe exedest
+		)
 	link <- relPathDirToFile (top </> exedir) (top ++ linker)
 	unlessM (doesFileExist (top </> exelink)) $
 		createSymbolicLink link (top </> exelink)
@@ -73,18 +80,6 @@ installLinkerShim top linker exe = do
 		[ "#!/bin/sh"
 		, "GIT_ANNEX_PROGRAMPATH=\"$0\""
 		, "export GIT_ANNEX_PROGRAMPATH"
-#ifdef MIN_VERSION_GLASGOW_HASKELL
-#if ! MIN_VERSION_GLASGOW_HASKELL(7,10,0,0)
-#define NEED_LOCPATH_WORKAROUND
-#endif
-#else
-#define NEED_LOCPATH_WORKAROUND
-#endif
-#ifdef NEED_LOCPATH_WORKAROUND
-		-- workaround for https://ghc.haskell.org/trac/ghc/ticket/7695
-		, "LOCPATH=/dev/null"
-		, "export LOCPATH"
-#endif
 		, "exec \"$GIT_ANNEX_DIR/" ++ exelink ++ "\" --library-path \"$GIT_ANNEX_LD_LIBRARY_PATH\" \"$GIT_ANNEX_DIR/shimmed/" ++ base ++ "/" ++ base ++ "\" \"$@\""
 		]
 	modifyFileMode exe $ addModes executeModes
@@ -95,15 +90,6 @@ installLinkerShim top linker exe = do
 	exedest = top </> shimdir </> base
 	exelink = exedir </> base
 
-{- Converting symlinks to hard links simplifies the binary shimming
- - process. -}
-symToHardLink :: FilePath -> IO ()
-symToHardLink f = whenM (isSymbolicLink <$> getSymbolicLinkStatus f) $ do
-	l <- readSymbolicLink f
-	let absl = absPathFrom (parentDir f) l
-	nukeFile f
-	createLink absl f
-
 installFile :: FilePath -> FilePath -> IO ()
 installFile top f = do
 	createDirectoryIfMissing True destdir
@@ -115,7 +101,7 @@ checkExe :: FilePath -> IO Bool
 checkExe f
 	| ".so" `isSuffixOf` f = return False
 	| otherwise = ifM (isExecutable . fileMode <$> getFileStatus f)
-		( checkFileExe <$> readProcess "file" [f]
+		( checkFileExe <$> readProcess "file" ["-L", f]
 		, return False
 		)
 
