@@ -210,7 +210,7 @@ parseAllOption = flag' WantAllKeys
 	)
 
 parseKey :: Monad m => String -> m Key
-parseKey = maybe (fail "invalid key") return . file2key
+parseKey = maybe (fail "invalid key") return . deserializeKey
 
 -- Options to match properties of annexed files.
 annexedMatchingOptions :: [GlobalOption]
@@ -410,4 +410,4 @@ completeRemotes = completer $ mkCompleter $ \input -> do
 		
 completeBackends :: HasCompleter f => Mod f a
 completeBackends = completeWith $
-	map (formatKeyVariety . Backend.backendVariety) Backend.list
+	map (decodeBS . formatKeyVariety . Backend.backendVariety) Backend.list
