@@ -28,7 +28,6 @@ import Types.UrlContents
 import Annex.FileMatcher
 import Logs.Location
 import Utility.Metered
-import Utility.FileSystemEncoding
 import Utility.HtmlDetect
 import Utility.Path.Max
 import qualified Annex.Transfer as Transfer
@@ -401,7 +400,7 @@ addWorkTree u url file key mtmp = case mtmp of
 			else void $ Command.Add.addSmall file
   where
 	go = do
-		maybeShowJSON $ JSONChunk [("key", key2file key)]
+		maybeShowJSON $ JSONChunk [("key", serializeKey key)]
 		setUrlPresent key url
 		logChange key u InfoPresent
 		ifM (addAnnexedFile file key mtmp)
