@@ -1,6 +1,6 @@
 {- git-annex command
  -
- - Copyright 2016 Joey Hess <id@joeyh.name>
+ - Copyright 2016-2018 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -16,7 +16,12 @@ cmd = notBareRepo $ notDirect $ noDaemonRunning $
 		paramNothing (seek <$$> optParser)
 
 optParser :: CmdParamsDesc -> Parser Adjustment
-optParser _ = 
+optParser _ =
+	(LinkAdjustment <$> linkAdjustmentParser)
+	<|> (PresenceAdjustment <$> presenceAdjustmentParser <*> maybeLinkAdjustmentParser)
+
+linkAdjustmentParser :: Parser LinkAdjustment
+linkAdjustmentParser =
 	flag' UnlockAdjustment
 		( long "unlock"
 		<> help "unlock annexed files"
@@ -25,12 +30,16 @@ optParser _ =
 		( long "fix"
 		<> help "fix symlinks to annnexed files"
 		)
-	{- Not ready yet
-	<|> flag' HideMissingAdjustment
+
+maybeLinkAdjustmentParser :: Parser (Maybe LinkAdjustment)
+maybeLinkAdjustmentParser = Just <$> linkAdjustmentParser <|> pure Nothing
+
+presenceAdjustmentParser :: Parser PresenceAdjustment
+presenceAdjustmentParser =
+	flag' HideMissingAdjustment
 		( long "hide-missing"
-		<> help "omit annexed files whose content is not present"
+		<> help "hide annexed files whose content is not present"
 		)
-	-}
 
 seek :: Adjustment -> CommandSeek
 seek = commandAction . start
