@@ -14,13 +14,13 @@ import Types.KeySource
 cmd :: Command
 cmd = noCommit $ noMessages $ dontCheck repoExists $
 	command "calckey" SectionPlumbing 
-		"calculates the key that would be used to refer to a file"
+		"calulate key for a file"
 		(paramRepeating paramFile)
 		(batchable run (pure ()))
 
 run :: () -> String -> Annex Bool
 run _ file = genKey (KeySource file file Nothing) Nothing >>= \case
 	Just (k, _) -> do
-		liftIO $ putStrLn $ key2file k
+		liftIO $ putStrLn $ serializeKey k
 		return True
 	Nothing -> return False
