@@ -23,7 +23,7 @@ cmd = noCommit $ dontCheck repoExists $
 		paramNothing (withParams seek)
 
 seek :: CmdParams -> CommandSeek
-seek = withNothing start
+seek = withNothing (commandAction start)
 
 start :: CommandStart
 start = do
