@@ -21,7 +21,7 @@ cmd = notBareRepo $ noDaemonRunning $
 		paramNothing (withParams seek)
 
 seek :: CmdParams -> CommandSeek
-seek = withNothing start
+seek = withNothing (commandAction start)
 
 start :: CommandStart
 start = ifM versionSupportsDirectMode
