@@ -54,10 +54,10 @@ parseDropFromOption = parseRemoteOption <$> strOption
 seek :: DropOptions -> CommandSeek
 seek o = allowConcurrentOutput $
 	case batchOption o of
-		Batch -> batchFilesMatching go
+		Batch fmt -> batchFilesMatching fmt go
 		NoBatch -> withKeyOptions (keyOptions o) (autoMode o)
-			(startKeys o)
-			(withFilesInGit go)
+			(commandAction . startKeys o)
+			(withFilesInGit (commandAction . go))
 			=<< workTreeItems (dropFiles o)
   where
 	go = whenAnnexed $ start o
@@ -68,7 +68,7 @@ start o file key = start' o key afile (mkActionItem afile)
 	afile = AssociatedFile (Just file)
 
 start' :: DropOptions -> Key -> AssociatedFile -> ActionItem -> CommandStart
-start' o key afile ai = do
+start' o key afile ai = onlyActionOn key $ do
 	from <- maybe (pure Nothing) (Just <$$> getParsed) (dropFrom o)
 	checkDropAuto (autoMode o) from afile key $ \numcopies ->
 		stopUnless (want from) $
@@ -84,8 +84,8 @@ start' o key afile ai = do
 			| autoMode o = wantDrop False (Remote.uuid <$> from) (Just key) afile
 			| otherwise = return True
 
-startKeys :: DropOptions -> Key -> ActionItem -> CommandStart
-startKeys o key = start' o key (AssociatedFile Nothing)
+startKeys :: DropOptions -> (Key, ActionItem) -> CommandStart
+startKeys o (key, ai) = start' o key (AssociatedFile Nothing) ai
 
 startLocal :: AssociatedFile -> ActionItem -> NumCopies -> Key -> [VerifiedCopy] -> CommandStart
 startLocal afile ai numcopies key preverified = stopUnless (inAnnex key) $ do
