@@ -205,8 +205,7 @@ performKey key backend numcopies = do
 check :: [Annex Bool] -> Annex Bool
 check cs = and <$> sequence cs
 
-{- Checks that symlinks points correctly to the annexed content.
- -}
+{- Checks that symlinks points correctly to the annexed content. -}
 fixLink :: Key -> FilePath -> Annex Bool
 fixLink key file = do
 	want <- calcRepo $ gitAnnexLink file key
@@ -215,7 +214,7 @@ fixLink key file = do
 	return True
   where
 	go want have
-		| want /= fromInternalGitPath have = do
+		| want /= fromInternalGitPath (fromRawFilePath have) = do
 			showNote "fixing link"
 			liftIO $ createDirectoryIfMissing True (parentDir file)
 			liftIO $ removeFile file
@@ -250,7 +249,7 @@ verifyLocationLog key keystatus ai = do
 	 - config was set. -}
 	when (present && not (cryptographicallySecure (keyVariety key))) $
 		whenM (annexSecureHashesOnly <$> Annex.getGitConfig) $
-			warning $ "** Despite annex.securehashesonly being set, " ++ obj ++ " has content present in the annex using an insecure " ++ formatKeyVariety (keyVariety key) ++ " key"
+			warning $ "** Despite annex.securehashesonly being set, " ++ obj ++ " has content present in the annex using an insecure " ++ decodeBS (formatKeyVariety (keyVariety key)) ++ " key"
 
 	{- In direct mode, modified files will show up as not present,
 	 - but that is expected and not something to do anything about. -}
@@ -424,7 +423,7 @@ checkKeyUpgrade backend key ai (AssociatedFile (Just file)) =
 				[ actionItemDesc ai key
 				, ": Can be upgraded to an improved key format. "
 				, "You can do so by running: git annex migrate --backend="
-				, formatKeyVariety (keyVariety key) ++ " "
+				, decodeBS (formatKeyVariety (keyVariety key)) ++ " "
 				, file
 				]
 			return True
@@ -498,7 +497,7 @@ checkBackendOr' bad backend key file ai postcheck =
 checkKeyNumCopies :: Key -> AssociatedFile -> NumCopies -> Annex Bool
 checkKeyNumCopies key afile numcopies = do
 	let (desc, hasafile) = case afile of
-		AssociatedFile Nothing -> (key2file key, False)
+		AssociatedFile Nothing -> (serializeKey key, False)
 		AssociatedFile (Just af) -> (af, True)
 	locs <- loggedLocations key
 	(untrustedlocations, otherlocations) <- trustPartition UnTrusted locs
@@ -562,7 +561,7 @@ badContentDirect file key = do
 badContentRemote :: Remote -> FilePath -> Key -> Annex String
 badContentRemote remote localcopy key = do
 	bad <- fromRepo gitAnnexBadDir
-	let destbad = bad </> key2file key
+	let destbad = bad </> keyFile key
 	movedbad <- ifM (inAnnex key <||> liftIO (doesFileExist destbad))
 		( return False
 		, do
