@@ -102,7 +102,7 @@ type StatState = StateT StatInfo Annex
 cmd :: Command
 cmd = noCommit $ withGlobalOptions [jsonOptions, annexedMatchingOptions] $
 	command "info" SectionQuery
-		"shows  information about the specified item or the repository as a whole"
+		"information about an item or the repository"
 		(paramRepeating paramItem) (seek <$$> optParser)
 
 data InfoOptions = InfoOptions
@@ -326,7 +326,7 @@ repository_mode = simpleStat "repository mode" $ lift $
 repo_list :: TrustLevel -> Stat
 repo_list level = stat n $ nojson $ lift $ do
 	us <- filter (/= NoUUID) . M.keys 
-		<$> (M.union <$> uuidMap <*> remoteMap Remote.name)
+		<$> (M.union <$> (M.map fromUUIDDesc <$> uuidDescMap) <*> remoteMap Remote.name)
 	rs <- fst <$> trustPartition level us
 	countRepoList (length rs)
 		-- This also handles json display.
@@ -410,7 +410,7 @@ key_size :: Key -> Stat
 key_size k = simpleStat "size" $ showSizeKeys $ foldKeys [k]
 
 key_name :: Key -> Stat
-key_name k = simpleStat "key" $ pure $ key2file k
+key_name k = simpleStat "key" $ pure $ serializeKey k
 
 content_present :: Key -> Stat
 content_present k = stat "present" $ json boolConfig $ lift $ inAnnex k
@@ -456,7 +456,7 @@ transfer_list = stat desc $ nojson $ lift $ do
 		[ ("transfer", toJSON' (formatDirection (transferDirection t)))
 		, ("key", toJSON' (transferKey t))
 		, ("file", toJSON' afile)
-		, ("remote", toJSON' (fromUUID (transferUUID t)))
+		, ("remote", toJSON' (fromUUID (transferUUID t) :: String))
 		]
 	  where
 		AssociatedFile afile = associatedFile i
@@ -481,7 +481,7 @@ disk_size = simpleStat "available local disk space" $
 
 backend_usage :: Stat
 backend_usage = stat "backend usage" $ json fmt $
-	ObjectMap . (M.mapKeys formatKeyVariety) . backendsKeys
+	ObjectMap . (M.mapKeys (decodeBS . formatKeyVariety)) . backendsKeys
 		<$> cachedReferencedData
   where
 	fmt = multiLine . map (\(b, n) -> b ++ ": " ++ show n) . sort . M.toList . fromObjectMap
