@@ -21,7 +21,7 @@ cmd = noCommit $
 		paramNothing (withParams seek)
 
 seek :: CmdParams -> CommandSeek
-seek = withNothing start
+seek = withNothing (commandAction start)
 
 start :: CommandStart
 start = go =<< watchChangedRefs
