@@ -17,7 +17,7 @@ cmd = noMessages $ command "numcopies" SectionSetup
 	paramNumber (withParams seek)
 
 seek :: CmdParams -> CommandSeek
-seek = withWords start
+seek = withWords (commandAction . start)
 
 start :: [String] -> CommandStart
 start [] = startGet
