@@ -82,7 +82,7 @@ sendRequest :: Transfer -> TransferInfo -> Handle -> IO ()
 sendRequest t tinfo h = do
 	hPutStr h $ intercalate fieldSep
 		[ serialize (transferDirection t)
-		, maybe (serialize (fromUUID (transferUUID t)))
+		, maybe (serialize ((fromUUID (transferUUID t)) :: String))
 			(serialize . Remote.name)
 			(transferRemote tinfo)
 		, serialize (transferKey t)
@@ -126,5 +126,5 @@ instance TCSerialized RemoteName where
 	deserialize n = Just n
 
 instance TCSerialized Key where
-	serialize = key2file
-	deserialize = file2key
+	serialize = serializeKey
+	deserialize = deserializeKey
