@@ -30,7 +30,7 @@ mkcmd n d = notDirect $
 		command n SectionCommon d paramPaths (withParams seek)
 
 seek :: CmdParams -> CommandSeek
-seek ps = withFilesInGit (whenAnnexed start) =<< workTreeItems ps
+seek ps = withFilesInGit (commandAction . whenAnnexed start) =<< workTreeItems ps
 
 {- Before v6, the unlock subcommand replaces the symlink with a copy of
  - the file's content. In v6 and above, it converts the file from a symlink
