@@ -19,9 +19,6 @@ import Assistant.Install
 import Annex.Environment
 import Utility.WebApp
 import Utility.Daemon (checkDaemon)
-#ifdef __ANDROID__
-import Utility.Env
-#endif
 import Utility.UserInfo
 import Annex.Init
 import qualified Git
@@ -188,18 +185,7 @@ firstRun o = do
 			Annex.eval state $
 				startDaemon True True Nothing Nothing (listenAddress o) $ Just $
 					sendurlback v
-	sendurlback v _origout _origerr url _htmlshim = do
-		recordUrl url
-		putMVar v url
-
-recordUrl :: String -> IO ()
-#ifdef __ANDROID__
-{- The Android app has a menu item that opens the url recorded
- - in this file. -}
-recordUrl url = writeFile "/sdcard/git-annex.home/.git-annex-url" url
-#else
-recordUrl _ = noop
-#endif
+	sendurlback v _origout _origerr url _htmlshim = putMVar v url
 
 openBrowser :: Maybe FilePath -> FilePath -> String -> Maybe Handle -> Maybe Handle -> IO ()
 openBrowser mcmd htmlshim realurl outh errh = do
@@ -207,7 +193,6 @@ openBrowser mcmd htmlshim realurl outh errh = do
 	openBrowser' mcmd htmlshim' realurl outh errh
 
 openBrowser' :: Maybe FilePath -> FilePath -> String -> Maybe Handle -> Maybe Handle -> IO ()
-#ifndef __ANDROID__
 openBrowser' mcmd htmlshim realurl outh errh =
 	ifM osAndroid
 		{- Android does not support file:// urls well, but neither
@@ -216,20 +201,6 @@ openBrowser' mcmd htmlshim realurl outh errh =
 		( runbrowser realurl
 		, runbrowser (fileUrl htmlshim)
 		)
-#else
-openBrowser' mcmd htmlshim realurl outh errh = do
-	recordUrl realurl
-	{- Android's `am` command does not work reliably across the
-	 - wide range of Android devices. Intead, FIFO should be set to 
-	 - the filename of a fifo that we can write the URL to. -}
-	v <- getEnv "FIFO"
-	case v of
-		Nothing -> runbrowser realurl
-		Just f -> void $ forkIO $ do
-			fd <- openFd f WriteOnly Nothing defaultFileFlags
-			void $ fdWrite fd realurl
-			closeFd fd
-#endif
   where
 	runbrowser url = do
 		let p = case mcmd of
