@@ -11,11 +11,11 @@ module Creds (
 	setRemoteCredPair,
 	getRemoteCredPair,
 	getRemoteCredPairFor,
-	warnMissingCredPairFor,
+	missingCredPairFor,
 	getEnvCredPair,
-	writeCacheCreds,
-	readCacheCreds,
-	cacheCredsFile,
+	writeCreds,
+	readCreds,
+	credsFile,
 	removeCreds,
 	includeCredsInfo,
 ) where
@@ -34,12 +34,12 @@ import qualified Data.ByteString.Lazy.Char8 as L
 import qualified Data.Map as M
 import Utility.Base64
 
-{- A CredPair can be stored in a file, or in the environment, or perhaps
+{- A CredPair can be stored in a file, or in the environment, or
  - in a remote's configuration. -}
 data CredPairStorage = CredPairStorage
 	{ credPairFile :: FilePath
 	, credPairEnvironment :: (String, String)
-	, credPairRemoteKey :: Maybe RemoteConfigKey
+	, credPairRemoteKey :: RemoteConfigKey
 	}
 
 {- Stores creds in a remote's configuration, if the remote allows
@@ -57,9 +57,9 @@ setRemoteCredPair encsetup c gc storage mcreds = case mcreds of
 	Nothing -> maybe (return c) (setRemoteCredPair encsetup c gc storage . Just)
 		=<< getRemoteCredPair c gc storage
 	Just creds
-		| embedCreds c -> case credPairRemoteKey storage of
-			Nothing -> localcache creds
-			Just key -> storeconfig creds key =<< flip remoteCipher gc =<< localcache creds
+		| embedCreds c ->
+			let key = credPairRemoteKey storage
+			in storeconfig creds key =<< flip remoteCipher gc =<< localcache creds
 		| otherwise -> localcache creds
   where
 	localcache creds = do
@@ -83,16 +83,15 @@ getRemoteCredPair c gc storage = maybe fromcache (return . Just) =<< fromenv
   where
 	fromenv = liftIO $ getEnvCredPair storage
 	fromcache = maybe fromconfig (return . Just) =<< readCacheCredPair storage
-	fromconfig = case credPairRemoteKey storage of
-		Just key -> do
-			mcipher <- remoteCipher' c gc
-			case (M.lookup key c, mcipher) of
-				(Nothing, _) -> return Nothing
-				(Just enccreds, Just (cipher, storablecipher)) ->
-					fromenccreds enccreds cipher storablecipher
-				(Just bcreds, Nothing) ->
-					fromcreds $ fromB64 bcreds
-		Nothing -> return Nothing
+	fromconfig = do
+		let key = credPairRemoteKey storage
+		mcipher <- remoteCipher' c gc
+		case (M.lookup key c, mcipher) of
+			(Nothing, _) -> return Nothing
+			(Just enccreds, Just (cipher, storablecipher)) ->
+				fromenccreds enccreds cipher storablecipher
+			(Just bcreds, Nothing) ->
+				fromcreds $ fromB64 bcreds
 	fromenccreds enccreds cipher storablecipher = do
 		cmd <- gpgCmd <$> Annex.getGitConfig
 		mcreds <- liftIO $ catchMaybeIO $ decrypt cmd (c, gc) cipher
@@ -119,12 +118,12 @@ getRemoteCredPairFor :: String -> RemoteConfig -> RemoteGitConfig -> CredPairSto
 getRemoteCredPairFor this c gc storage = go =<< getRemoteCredPair c gc storage
   where
 	go Nothing = do
-		warnMissingCredPairFor this storage
+		warning $ missingCredPairFor this storage
 		return Nothing
 	go (Just credpair) = return $ Just credpair
 
-warnMissingCredPairFor :: String -> CredPairStorage -> Annex ()
-warnMissingCredPairFor this storage = warning $ unwords
+missingCredPairFor :: String -> CredPairStorage -> String
+missingCredPairFor this storage = unwords
 	[ "Set both", loginvar
 	, "and", passwordvar
 	, "to use", this
@@ -140,34 +139,36 @@ getEnvCredPair storage = liftM2 (,)
   where
 	(uenv, penv) = credPairEnvironment storage
 
+{- Writes a cred pair to local cache, unless prevented by configuration. -}
 writeCacheCredPair :: CredPair -> CredPairStorage -> Annex ()
-writeCacheCredPair credpair storage =
-	writeCacheCreds (encodeCredPair credpair) (credPairFile storage)
+writeCacheCredPair credpair storage = 
+	whenM (annexCacheCreds <$> Annex.getGitConfig) $
+		writeCreds (encodeCredPair credpair) (credPairFile storage)
+
+readCacheCredPair :: CredPairStorage -> Annex (Maybe CredPair)
+readCacheCredPair storage = maybe Nothing decodeCredPair
+	<$> readCreds (credPairFile storage)
+
+existsCacheCredPair :: CredPairStorage -> Annex Bool
+existsCacheCredPair storage = 
+	liftIO . doesFileExist =<< credsFile (credPairFile storage)
 
 {- Stores the creds in a file inside gitAnnexCredsDir that only the user
  - can read. -}
-writeCacheCreds :: Creds -> FilePath -> Annex ()
-writeCacheCreds creds file = do
+writeCreds :: Creds -> FilePath -> Annex ()
+writeCreds creds file = do
 	d <- fromRepo gitAnnexCredsDir
 	createAnnexDirectory d
 	liftIO $ writeFileProtected (d </> file) creds
 
-readCacheCredPair :: CredPairStorage -> Annex (Maybe CredPair)
-readCacheCredPair storage = maybe Nothing decodeCredPair
-	<$> readCacheCreds (credPairFile storage)
+readCreds :: FilePath -> Annex (Maybe Creds)
+readCreds f = liftIO . catchMaybeIO . readFileStrict =<< credsFile f
 
-readCacheCreds :: FilePath -> Annex (Maybe Creds)
-readCacheCreds f = liftIO . catchMaybeIO . readFileStrict =<< cacheCredsFile f
-
-cacheCredsFile :: FilePath -> Annex FilePath
-cacheCredsFile basefile = do
+credsFile :: FilePath -> Annex FilePath
+credsFile basefile = do
 	d <- fromRepo gitAnnexCredsDir
 	return $ d </> basefile
 
-existsCacheCredPair :: CredPairStorage -> Annex Bool
-existsCacheCredPair storage = 
-	liftIO . doesFileExist =<< cacheCredsFile (credPairFile storage)
-
 encodeCredPair :: CredPair -> Creds
 encodeCredPair (l, p) = unlines [l, p]
 
@@ -189,7 +190,7 @@ includeCredsInfo c storage info = do
 		Just _ -> do
 			let (uenv, penv) = credPairEnvironment storage
 			ret $ "from environment variables (" ++ unwords [uenv, penv] ++ ")"
-		Nothing -> case (`M.lookup` c) =<< credPairRemoteKey storage of
+		Nothing -> case (`M.lookup` c) (credPairRemoteKey storage) of
 			Nothing -> ifM (existsCacheCredPair storage)
 				( ret "stored locally"
 				, ret "not available"
