@@ -1,6 +1,6 @@
 {- git repository command queue
  -
- - Copyright 2010,2012 Joey Hess <id@joeyh.name>
+ - Copyright 2010-2018 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -12,6 +12,8 @@ module Git.Queue (
 	new,
 	addCommand,
 	addUpdateIndex,
+	addInternalAction,
+	InternalActionRunner(..),
 	size,
 	full,
 	flush,
@@ -24,7 +26,7 @@ import Git
 import Git.Command
 import qualified Git.UpdateIndex
 
-import qualified Data.Map as M
+import qualified Data.Map.Strict as M
 
 {- Queable actions that can be performed in a git repository. -}
 data Action
@@ -38,14 +40,27 @@ data Action
 		, getParams :: [CommandParam]
 		, getFiles :: [CommandParam]
 		} 
+	{- An internal action to run, on a list of files that can be added
+	 - to as the queue grows. -}
+	| InternalAction
+		{ getRunner :: InternalActionRunner
+		, getInternalFiles :: [(FilePath, IO Bool)]
+		}
+
+{- The String must be unique for each internal action. -}
+data InternalActionRunner = InternalActionRunner String (Repo -> [(FilePath, IO Bool)] -> IO ())
+
+instance Eq InternalActionRunner where
+	InternalActionRunner s1 _ == InternalActionRunner s2 _ = s1 == s2
 
 {- A key that can uniquely represent an action in a Map. -}
-data ActionKey = UpdateIndexActionKey | CommandActionKey String
+data ActionKey = UpdateIndexActionKey | CommandActionKey String | InternalActionKey String
 	deriving (Eq, Ord)
 
 actionKey :: Action -> ActionKey
 actionKey (UpdateIndexAction _) = UpdateIndexActionKey
 actionKey CommandAction { getSubcommand = s } = CommandActionKey s
+actionKey InternalAction { getRunner = InternalActionRunner s _ } = InternalActionKey s
 
 {- A queue of actions to perform (in any order) on a git repository,
  - with lists of files to perform them on. This allows coalescing 
@@ -91,6 +106,19 @@ addCommand subcommand params files q repo =
 	different (CommandAction { getSubcommand = s }) = s /= subcommand
 	different _ = True
 
+{- Adds an internal action to the queue. -}
+addInternalAction :: InternalActionRunner -> [(FilePath, IO Bool)] -> Queue -> Repo -> IO Queue
+addInternalAction runner files q repo =
+	updateQueue action different (length files) q repo
+  where
+	action = InternalAction
+		{ getRunner = runner
+		, getInternalFiles = files
+		}
+	
+	different (InternalAction { getRunner = r }) = r /= runner
+	different _ = True
+
 {- Adds an update-index streamer to the queue. -}
 addUpdateIndex :: Git.UpdateIndex.Streamer -> Queue -> Repo -> IO Queue
 addUpdateIndex streamer q repo =
@@ -117,13 +145,18 @@ updateQueue !action different sizeincrease q repo
 			, items = newitems
 			}
 		!newsize = size q' + sizeincrease
-		!newitems = M.insertWith' combineNewOld (actionKey action) action (items q')
+		!newitems = M.insertWith combineNewOld (actionKey action) action (items q')
 
+{- The new value comes first. It probably has a smaller list of files than
+ - the old value. So, the list append of the new value first is more
+ - efficient. -}
 combineNewOld :: Action -> Action -> Action
 combineNewOld (CommandAction _sc1 _ps1 fs1) (CommandAction sc2 ps2 fs2) =
 	CommandAction sc2 ps2 (fs1++fs2)
 combineNewOld (UpdateIndexAction s1) (UpdateIndexAction s2) =
 	UpdateIndexAction (s1++s2)
+combineNewOld (InternalAction _r1 fs1) (InternalAction r2 fs2) =
+	InternalAction r2 (fs1++fs2)
 combineNewOld anew _aold = anew
 
 {- Merges the contents of the second queue into the first.
@@ -172,3 +205,6 @@ runAction repo action@(CommandAction {}) = do
   where
 	gitparams = gitCommandLine
 		(Param (getSubcommand action):getParams action) repo
+runAction repo action@(InternalAction {}) =
+	let InternalActionRunner _ runner = getRunner action
+	in runner repo (getInternalFiles action)
