@@ -22,5 +22,5 @@ addWantDrop = addLimit $ Right $ const $ checkWant $
 
 checkWant :: (AssociatedFile -> Annex Bool) -> MatchInfo -> Annex Bool
 checkWant a (MatchingFile fi) = a (AssociatedFile (Just $ matchFile fi))
-checkWant _ (MatchingKey _) = return False
+checkWant a (MatchingKey _ af) = a af
 checkWant _ (MatchingInfo {}) = return False
