@@ -1,6 +1,6 @@
 {- git-annex repository-global config log
  -
- - Copyright 2017 Joey Hess <id@joeyh.name>
+ - Copyright 2017-2019 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -20,6 +20,9 @@ import Logs.MapLog
 import qualified Annex.Branch
 
 import qualified Data.Map as M
+import qualified Data.ByteString.Lazy as L
+import qualified Data.Attoparsec.ByteString.Lazy as A
+import Data.ByteString.Builder
 
 type ConfigName = String
 type ConfigValue = String
@@ -34,7 +37,7 @@ setGlobalConfig' :: ConfigName -> ConfigValue -> Annex ()
 setGlobalConfig' name new = do
 	c <- liftIO currentVectorClock
 	Annex.Branch.change configLog $ 
-		showMapLog id id . changeMapLog c name new . parseGlobalConfig
+		buildGlobalConfig . changeMapLog c name new . parseGlobalConfig
 
 unsetGlobalConfig :: ConfigName -> Annex ()
 unsetGlobalConfig name = do
@@ -46,8 +49,16 @@ unsetGlobalConfig name = do
 getGlobalConfig :: ConfigName -> Annex (Maybe ConfigValue)
 getGlobalConfig name = M.lookup name <$> loadGlobalConfig
 
-parseGlobalConfig :: String -> MapLog ConfigName ConfigValue
-parseGlobalConfig = parseMapLog Just Just
+buildGlobalConfig :: MapLog ConfigName ConfigValue -> Builder
+buildGlobalConfig = buildMapLog fieldbuilder valuebuilder
+  where
+	fieldbuilder = byteString . encodeBS
+	valuebuilder = byteString . encodeBS
+
+parseGlobalConfig :: L.ByteString -> MapLog ConfigName ConfigValue
+parseGlobalConfig = parseMapLog string string
+  where
+	string = decodeBS <$> A.takeByteString
 
 loadGlobalConfig :: Annex (M.Map ConfigName ConfigValue)
 loadGlobalConfig = M.filter (not . null) . simpleMap . parseGlobalConfig
