@@ -13,6 +13,8 @@ module Logs.Difference (
 ) where
 
 import qualified Data.Map as M
+import qualified Data.Attoparsec.ByteString as A
+import Data.ByteString.Builder
 
 import Annex.Common
 import Types.Difference
@@ -25,7 +27,9 @@ recordDifferences :: Differences -> UUID -> Annex ()
 recordDifferences ds@(Differences {}) uuid = do
 	c <- liftIO currentVectorClock
 	Annex.Branch.change differenceLog $
-		showLog id . changeLog c uuid (showDifferences ds) . parseLog Just
+		buildLog byteString 
+			. changeLog c uuid (encodeBS $ showDifferences ds) 
+			. parseLog A.takeByteString
 recordDifferences UnknownDifferences _ = return ()
 
 -- Map of UUIDs that have Differences recorded.
@@ -35,5 +39,4 @@ recordedDifferences :: Annex (M.Map UUID Differences)
 recordedDifferences = parseDifferencesLog <$> Annex.Branch.get differenceLog
 
 recordedDifferencesFor :: UUID -> Annex Differences
-recordedDifferencesFor u = fromMaybe mempty . M.lookup u 
-	<$> recordedDifferences
+recordedDifferencesFor u = fromMaybe mempty . M.lookup u <$> recordedDifferences
