@@ -1,6 +1,6 @@
 {- git-annex presence log, pure operations
  -
- - Copyright 2010-2013 Joey Hess <id@joeyh.name>
+ - Copyright 2010-2019 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -13,30 +13,44 @@ import Logs.Line
 import Utility.QuickCheck
 
 import qualified Data.Map as M
+import qualified Data.ByteString.Lazy as L
+import qualified Data.ByteString as S
+import qualified Data.ByteString.Char8 as C8
+import qualified Data.Attoparsec.ByteString.Lazy as A
+import Data.Attoparsec.ByteString.Char8 (char, anyChar)
+import Data.ByteString.Builder
+
+newtype LogInfo = LogInfo { fromLogInfo :: S.ByteString }
+	deriving (Show, Eq, Ord)
 
 data LogLine = LogLine
 	{ date :: VectorClock
 	, status :: LogStatus
-	, info :: String
-	} deriving (Eq)
-
-instance Show LogLine where
-	show l = "LogLine " ++ formatVectorClock (date l) ++ show (status l) ++ " " ++ show (info l)
+	, info :: LogInfo
+	} deriving (Eq, Show)
 
 data LogStatus = InfoPresent | InfoMissing | InfoDead
 	deriving (Eq, Show, Bounded, Enum)
 
-{- Parses a log file. Unparseable lines are ignored. -}
-parseLog :: String -> [LogLine]
-parseLog = mapMaybe parseline . splitLines
-  where
-	parseline l = LogLine
-		<$> parseVectorClock c
-		<*> parseStatus s
-		<*> pure rest
-	  where
-		(c, pastc) = separate (== ' ') l
-		(s, rest) = separate (== ' ') pastc
+parseLog :: L.ByteString -> [LogLine]
+parseLog = fromMaybe [] . A.maybeResult . A.parse logParser
+
+logParser :: A.Parser [LogLine]
+logParser = parseLogLines $ LogLine
+	<$> vectorClockParser
+	<* char ' '
+	<*> statusParser
+	<* char ' '
+	<*> (LogInfo <$> A.takeByteString)
+
+statusParser :: A.Parser LogStatus
+statusParser = do
+	c <- anyChar
+	case c of
+		'1' -> return InfoPresent
+		'0' -> return InfoMissing
+		'X' -> return InfoDead
+		_ -> fail "unknown status character"
 
 parseStatus :: String -> Maybe LogStatus
 parseStatus "1" = Just InfoPresent
@@ -44,17 +58,19 @@ parseStatus "0" = Just InfoMissing
 parseStatus "X" = Just InfoDead
 parseStatus _ = Nothing
 
-{- Generates a log file. -}
-showLog :: [LogLine] -> String
-showLog = unlines . map genline
+buildLog :: [LogLine] -> Builder
+buildLog = mconcat . map genline
   where
-	genline (LogLine c s i) = unwords [formatVectorClock c, genstatus s, i]
-	genstatus InfoPresent = "1"
-	genstatus InfoMissing = "0"
-	genstatus InfoDead = "X"
+	genline (LogLine c s (LogInfo i)) = 
+		buildVectorClock c <> sp <> genstatus s <> sp <> byteString i <> nl
+	sp = charUtf8 ' '
+	nl = charUtf8 '\n'
+	genstatus InfoPresent = charUtf8 '1'
+	genstatus InfoMissing = charUtf8 '0'
+	genstatus InfoDead = charUtf8 'X'
 
 {- Given a log, returns only the info that is are still in effect. -}
-getLog :: String -> [String]
+getLog :: L.ByteString -> [LogInfo]
 getLog = map info . filterPresent . parseLog
 
 {- Returns the info from LogLines that are in effect. -}
@@ -66,7 +82,7 @@ filterPresent = filter (\l -> InfoPresent == status l) . compactLog
 compactLog :: [LogLine] -> [LogLine]
 compactLog = mapLog . logMap
 
-type LogMap = M.Map String LogLine
+type LogMap = M.Map LogInfo LogLine
 
 mapLog :: LogMap -> [LogLine]
 mapLog = M.elems
@@ -101,9 +117,11 @@ instance Arbitrary LogLine where
 	arbitrary = LogLine
 		<$> arbitrary
 		<*> elements [minBound..maxBound]
-		<*> arbitrary `suchThat`
-			(\c -> '\n' `notElem` c && '\r' `notElem` c)
+		<*> (LogInfo <$> arbinfo)
+	  where
+		arbinfo = (encodeBS <$> arbitrary) `suchThat`
+			(\b -> C8.notElem '\n' b && C8.notElem '\r' b)
 
-prop_parse_show_log :: [LogLine] -> Bool
-prop_parse_show_log l = parseLog (showLog l) == l
+prop_parse_build_log :: [LogLine] -> Bool
+prop_parse_build_log l = parseLog (toLazyByteString (buildLog l)) == l
 
