@@ -35,4 +35,4 @@ setLog :: (SingleValueSerializable v) => FilePath -> v -> Annex ()
 setLog f v = do
 	c <- liftIO currentVectorClock
 	let ent = LogEntry c v
-	Annex.Branch.change f $ \_old -> showLog (S.singleton ent)
+	Annex.Branch.change f $ \_old -> buildLog (S.singleton ent)
