@@ -18,7 +18,7 @@ import Utility.Metered
 import Utility.Percentage
 import Utility.PID
 import Annex.LockPool
-import Logs.TimeStamp
+import Utility.TimeStamp
 import Logs.File
 
 import Data.Time.Clock
@@ -95,7 +95,7 @@ startTransferInfo afile = TransferInfo
  - interrupted.
  -}
 checkTransfer :: Transfer -> Annex (Maybe TransferInfo)
-checkTransfer t = do
+checkTransfer t = debugLocks $ do
 	tfile <- fromRepo $ transferFile t
 	let lck = transferLockFile tfile
 	let cleanstale = do
