@@ -1,6 +1,6 @@
 {- git-annex output messages, including concurrent output to display regions
  -
- - Copyright 2010-2016 Joey Hess <id@joeyh.name>
+ - Copyright 2010-2018 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -11,27 +11,31 @@ import Common
 import Annex
 import Types.Messages
 import Messages.Concurrent
-import Messages.JSON
+import qualified Messages.JSON as JSON
+import Messages.JSON (JSONBuilder)
 
 withMessageState :: (MessageState -> Annex a) -> Annex a
 withMessageState a = Annex.getState Annex.output >>= a
 
 outputMessage :: JSONBuilder -> String -> Annex ()
-outputMessage jsonbuilder msg = withMessageState $ \s -> case outputType s of
+outputMessage = outputMessage' bufferJSON
+
+outputMessage' :: (JSONBuilder -> MessageState -> Annex Bool) -> JSONBuilder -> String -> Annex ()
+outputMessage' jsonoutputter jsonbuilder msg = withMessageState $ \s -> case outputType s of
 	NormalOutput
 		| concurrentOutputEnabled s -> concurrentMessage s False msg q
 		| otherwise -> liftIO $ flushed $ putStr msg
-	JSONOutput _ -> void $ outputJSON jsonbuilder s
+	JSONOutput _ -> void $ jsonoutputter jsonbuilder s
 	QuietOutput -> q
 
 -- Buffer changes to JSON until end is reached and then emit it.
-outputJSON :: JSONBuilder -> MessageState -> Annex Bool
-outputJSON jsonbuilder s = case outputType s of
-	JSONOutput _
+bufferJSON :: JSONBuilder -> MessageState -> Annex Bool
+bufferJSON jsonbuilder s = case outputType s of
+	JSONOutput jsonoptions
 		| endjson -> do
 			Annex.changeState $ \st -> 
 				st { Annex.output = s { jsonBuffer = Nothing } }
-			maybe noop (liftIO . flushed . emit) json
+			maybe noop (liftIO . flushed . JSON.emit . JSON.finalize jsonoptions) json
 			return True
 		| otherwise -> do
 			Annex.changeState $ \st ->
@@ -46,11 +50,24 @@ outputJSON jsonbuilder s = case outputType s of
 		Nothing -> Nothing
 		Just b -> Just (b, False)
 
+-- Immediately output JSON.
+outputJSON :: JSONBuilder -> MessageState -> Annex Bool
+outputJSON jsonbuilder s = case outputType s of
+	JSONOutput _ -> do
+		maybe noop (liftIO . flushed . JSON.emit)
+			(fst <$> jsonbuilder Nothing)
+		return True
+	_ -> return False
+
 outputError :: String -> Annex ()
-outputError msg = withMessageState $ \s ->
-	if concurrentOutputEnabled s
-		then concurrentMessage s True msg go
-		else go
+outputError msg = withMessageState $ \s -> case (outputType s, jsonBuffer s) of
+        (JSONOutput jsonoptions, Just jb) | jsonErrorMessages jsonoptions ->
+		let jb' = Just (JSON.addErrorMessage (lines msg) jb)
+		in Annex.changeState $ \st ->
+			st { Annex.output = s { jsonBuffer = jb' } }
+	_
+		| concurrentOutputEnabled s -> concurrentMessage s True msg go
+		| otherwise -> go
   where
 	go = liftIO $ do
 		hFlush stdout
