@@ -83,7 +83,6 @@ data Message
 	| DATA Len -- followed by bytes of data
 	| VALIDITY Validity
 	| ERROR String
-	| ProtocolEOF
 	deriving (Show)
 
 instance Proto.Sendable Message where
@@ -109,7 +108,6 @@ instance Proto.Sendable Message where
 	formatMessage (VALIDITY Invalid) = ["INVALID"]
 	formatMessage (DATA len) = ["DATA", Proto.serialize len]
 	formatMessage (ERROR err) = ["ERROR", Proto.serialize err]
-	formatMessage (ProtocolEOF) = []
 
 instance Proto.Receivable Message where
 	parseCommand "AUTH" = Proto.parse2 AUTH
@@ -240,8 +238,12 @@ data LocalF c
 	-- present.
 	| ReadContent Key AssociatedFile Offset (L.ByteString -> Proto Validity -> Proto Bool) (Bool -> c)
 	-- ^ Reads the content of a key and sends it to the callback.
-	-- If the content is not available, sends L.empty to the callback.
-	-- Note that the content may change while it's being sent.
+	-- Must run the callback, or terminate the protocol connection.
+	--
+	-- May send any amount of data, including L.empty if the content is
+	-- not available. The callback must deal with that.
+	--
+	-- And the content may change while it's being sent.
 	-- The callback is passed a validity check that it can run after
 	-- sending the content to detect when this happened.
 	| StoreContent Key AssociatedFile Offset Len (Proto L.ByteString) (Proto (Maybe Validity)) (Bool -> c)
@@ -249,6 +251,9 @@ data LocalF c
 	-- Once the whole content of the key has been stored, moves the
 	-- temp file into place as the content of the key, and returns True.
 	--
+	-- Must consume the whole lazy ByteString, or if unable to do
+	-- so, terminate the protocol connection.
+	--
 	-- If the validity check is provided and fails, the content was
 	-- changed while it was being sent, so verificiation of the
 	-- received content should be forced.
@@ -369,8 +374,6 @@ serverLoop :: (Message -> Proto (ServerHandler a)) -> Proto (Maybe a)
 serverLoop a = do
 	mcmd <- net receiveMessage
 	case mcmd of
-		-- Stop loop at EOF
-		Just ProtocolEOF -> return Nothing
 		-- When the client sends ERROR to the server, the server
 		-- gives up, since it's not clear what state the client
 		-- is in, and so not possible to recover.
