@@ -113,7 +113,7 @@ gen r u c gc
 			-- and have no protection against redirects to
 			-- local private web servers, or in some cases
 			-- to file:// urls.
-			, retrievalSecurityPolicy = RetrievalVerifiableKeysSecure
+			, retrievalSecurityPolicy = mkRetrievalVerifiableKeysSecure gc
 			, removeKey = removeKeyDummy
 			, lockContent = Nothing
 			, checkPresent = checkPresentDummy
@@ -416,9 +416,9 @@ handleRequest' st external req mp responsehandler
 			<$> getRemoteState (externalUUID external) key
 		send $ VALUE state
 	handleRemoteRequest (SETURLPRESENT key url) =
-		setUrlPresent (externalUUID external) key url
+		setUrlPresent key url
 	handleRemoteRequest (SETURLMISSING key url) =
-		setUrlMissing (externalUUID external) key url
+		setUrlMissing key url
 	handleRemoteRequest (SETURIPRESENT key uri) =
 		withurl (SETURLPRESENT key) uri
 	handleRemoteRequest (SETURIMISSING key uri) =
@@ -438,7 +438,7 @@ handleRequest' st external req mp responsehandler
 	credstorage setting = CredPairStorage
 		{ credPairFile = base
 		, credPairEnvironment = (base ++ "login", base ++ "password")
-		, credPairRemoteKey = Just setting
+		, credPairRemoteKey = setting
 		}
 	  where
 		base = replace "/" "_" $ fromUUID (externalUUID external) ++ "-" ++ setting
@@ -689,10 +689,6 @@ checkUrlM external url =
 	handleRequest external (CHECKURL url) Nothing $ \req -> case req of
 		CHECKURL_CONTENTS sz f -> result $ UrlContents sz $
 			if null f then Nothing else Just $ mkSafeFilePath f
-		-- Treat a single item multi response specially to
-		-- simplify the external remote implementation.
-		CHECKURL_MULTI ((_, sz, f):[]) ->
-			result $ UrlContents sz $ Just $ mkSafeFilePath f
 		CHECKURL_MULTI l -> result $ UrlMulti $ map mkmulti l
 		CHECKURL_FAILURE errmsg -> Just $ giveup errmsg
 		UNSUPPORTED_REQUEST -> giveup "CHECKURL not implemented by external special remote"
