@@ -1,6 +1,6 @@
 {- S3 remotes
  -
- - Copyright 2011-2018 Joey Hess <id@joeyh.name>
+ - Copyright 2011-2019 Joey Hess <id@joeyh.name>
  -
  - Licensed under the GNU GPL version 3 or higher.
  -}
@@ -24,6 +24,7 @@ import qualified Data.Map as M
 import qualified Data.Set as S
 import qualified System.FilePath.Posix as Posix
 import Data.Char
+import Data.String
 import Network.Socket (HostName)
 import Network.HTTP.Conduit (Manager)
 import Network.HTTP.Client (responseStatus, responseBody, RequestBody(..))
@@ -47,6 +48,7 @@ import Remote.Helper.Export
 import qualified Remote.Helper.AWS as AWS
 import Creds
 import Annex.UUID
+import Annex.Magic
 import Logs.Web
 import Logs.MetaData
 import Types.MetaData
@@ -74,10 +76,11 @@ gen :: Git.Repo -> UUID -> RemoteConfig -> RemoteGitConfig -> Annex (Maybe Remot
 gen r u c gc = do
 	cst <- remoteCost gc expensiveRemoteCost
 	info <- extractS3Info c
-	return $ new cst info
+	magic <- liftIO initMagicMimeType
+	return $ new cst info magic
   where
-	new cst info = Just $ specialRemote c
-		(prepareS3Handle this $ store this info)
+	new cst info magic = Just $ specialRemote c
+		(prepareS3Handle this $ store this info magic)
 		(prepareS3HandleMaybe this $ retrieve this c info)
 		(prepareS3Handle this $ remove info)
 		(prepareS3HandleMaybe this $ checkKey this c info)
@@ -99,7 +102,7 @@ gen r u c gc = do
 			, checkPresentCheap = False
 			, exportActions = withS3HandleMaybe c gc u $ \mh -> 
 				return $ ExportActions
-					{ storeExport = storeExportS3 u info mh
+					{ storeExport = storeExportS3 u info mh magic
 					, retrieveExport = retrieveExportS3 u info mh
 					, removeExport = removeExportS3 u info mh
 					, checkPresentExport = checkPresentExportS3 u info mh
@@ -145,6 +148,7 @@ s3Setup' ss u mcreds c gc
 		]
 		
 	use fullconfig = do
+		enableBucketVersioning ss fullconfig gc u
 		gitConfigSpecialRemote u fullconfig [("s3", "true")]
 		return (fullconfig, u)
 
@@ -190,16 +194,16 @@ prepareS3HandleMaybe :: Remote -> (Maybe S3Handle -> helper) -> Preparer helper
 prepareS3HandleMaybe r = resourcePrepare $ const $
 	withS3HandleMaybe (config r) (gitconfig r) (uuid r)
 
-store :: Remote -> S3Info -> S3Handle -> Storer
-store _r info h = fileStorer $ \k f p -> do
-	void $ storeHelper info h f (T.pack $ bucketObject info k) p
+store :: Remote -> S3Info -> Maybe Magic -> S3Handle -> Storer
+store _r info magic h = fileStorer $ \k f p -> do
+	void $ storeHelper info h magic f (T.pack $ bucketObject info k) p
 	-- Store public URL to item in Internet Archive.
 	when (isIA info && not (isChunkKey k)) $
 		setUrlPresent k (iaPublicUrl info (bucketObject info k))
 	return True
 
-storeHelper :: S3Info -> S3Handle -> FilePath -> S3.Object -> MeterUpdate -> Annex (Maybe S3VersionID)
-storeHelper info h f object p = case partSize info of
+storeHelper :: S3Info -> S3Handle -> Maybe Magic -> FilePath -> S3.Object -> MeterUpdate -> Annex (Maybe S3VersionID)
+storeHelper info h magic f object p = case partSize info of
 	Just partsz | partsz > 0 -> do
 		fsz <- liftIO $ getFileSize f
 		if fsz > partsz
@@ -208,16 +212,20 @@ storeHelper info h f object p = case partSize info of
 	_ -> singlepartupload
   where
 	singlepartupload = do
+		contenttype <- getcontenttype
 		rbody <- liftIO $ httpBodyStorer f p
-		r <- sendS3Handle h $ putObject info object rbody
+		r <- sendS3Handle h $ (putObject info object rbody)
+			{ S3.poContentType = encodeBS <$> contenttype }
 		return (mkS3VersionID object (S3.porVersionId r))
 	multipartupload fsz partsz = do
 #if MIN_VERSION_aws(0,16,0)
+		contenttype <- getcontenttype
 		let startreq = (S3.postInitiateMultipartUpload (bucket info) object)
 				{ S3.imuStorageClass = Just (storageClass info)
 				, S3.imuMetadata = metaHeaders info
 				, S3.imuAutoMakeBucket = isIA info
 				, S3.imuExpires = Nothing -- TODO set some reasonable expiry
+				, S3.imuContentType = fromString <$> contenttype
 				}
 		uploadid <- S3.imurUploadId <$> sendS3Handle h startreq
 
@@ -254,6 +262,8 @@ storeHelper info h f object p = case partSize info of
 		warning $ "Cannot do multipart upload (partsize " ++ show partsz ++ ") of large file (" ++ show fsz ++ "); built with too old a version of the aws library."
 		singlepartupload
 #endif
+	getcontenttype = liftIO $
+		maybe (pure Nothing) (flip getMagicMimeType f) magic
 
 {- Implemented as a fileRetriever, that uses conduit to stream the chunks
  - out to the file. Would be better to implement a byteRetriever, but
@@ -343,16 +353,16 @@ checkKeyHelper info h loc = do
 			| otherwise = Nothing
 #endif
 
-storeExportS3 :: UUID -> S3Info -> Maybe S3Handle -> FilePath -> Key -> ExportLocation -> MeterUpdate -> Annex Bool
-storeExportS3 u info (Just h) f k loc p = 
+storeExportS3 :: UUID -> S3Info -> Maybe S3Handle -> Maybe Magic -> FilePath -> Key -> ExportLocation -> MeterUpdate -> Annex Bool
+storeExportS3 u info (Just h) magic f k loc p = 
 	catchNonAsync go (\e -> warning (show e) >> return False)
   where
 	go = do
 		let o = T.pack $ bucketExportLocation info loc
-		storeHelper info h f o p
+		storeHelper info h magic f o p
 			>>= setS3VersionID info u k
 		return True
-storeExportS3 u _ Nothing _ _ _ _ = do
+storeExportS3 u _ Nothing _ _ _ _ _ = do
 	warning $ needS3Creds u
 	return False
 
@@ -373,7 +383,7 @@ retrieveExportS3 u info mh _k loc f p =
 	exporturl = bucketExportLocation info loc
 
 removeExportS3 :: UUID -> S3Info -> Maybe S3Handle -> Key -> ExportLocation -> Annex Bool
-removeExportS3 _u info (Just h) _k loc = 
+removeExportS3 u info (Just h) k loc = checkVersioning info u k $
 	catchNonAsync go (\e -> warning (show e) >> return False)
   where
 	go = do
@@ -396,7 +406,8 @@ checkPresentExportS3 u info Nothing k loc = case getPublicUrlMaker info of
 
 -- S3 has no move primitive; copy and delete.
 renameExportS3 :: UUID -> S3Info -> Maybe S3Handle -> Key -> ExportLocation -> ExportLocation -> Annex Bool
-renameExportS3 _u info (Just h) _k src dest = catchNonAsync go (\_ -> return False)
+renameExportS3 u info (Just h) k src dest = checkVersioning info u k $ 
+	catchNonAsync go (\_ -> return False)
   where
 	go = do
 		let co = S3.copyObject (bucket info) dstobject
@@ -416,8 +427,8 @@ renameExportS3 u _ Nothing _ _ _ = do
  - UUID file within the bucket.
  -
  - Some ACLs can allow read/write to buckets, but not querying them,
- - so first check if the UUID file already exists and we can skip doing
- - anything.
+ - so first check if the UUID file already exists and we can skip creating
+ - it.
  -}
 genBucket :: RemoteConfig -> RemoteGitConfig -> UUID -> Annex ()
 genBucket c gc u = do
@@ -848,3 +859,55 @@ s3VersionIDPublicUrl mk info (S3VersionID obj vid) = mk info $ concat
 getS3VersionIDPublicUrls :: (S3Info -> BucketObject -> URLString) -> S3Info -> UUID -> Key -> Annex [URLString]
 getS3VersionIDPublicUrls mk info u k =
 	map (s3VersionIDPublicUrl mk info) <$> getS3VersionID u k
+
+-- Enable versioning on the bucket can only be done at init time;
+-- setting versioning in a bucket that git-annex has already exported
+-- files to risks losing the content of those un-versioned files.
+enableBucketVersioning :: SetupStage -> RemoteConfig -> RemoteGitConfig -> UUID -> Annex ()
+#if MIN_VERSION_aws(0,22,0)
+enableBucketVersioning ss c gc u = do
+#else
+enableBucketVersioning ss c _ _ = do
+#endif
+	info <- extractS3Info c
+	case ss of
+		Init -> when (versioning info) $
+			enableversioning (bucket info)
+		Enable oldc -> do
+			oldinfo <- extractS3Info oldc
+			when (versioning info /= versioning oldinfo) $
+				giveup "Cannot change versioning= of existing S3 remote."
+  where
+	enableversioning b = do
+#if MIN_VERSION_aws(0,22,0)
+		showAction "enabling bucket versioning"
+		withS3Handle c gc u $ \h ->
+			void $ sendS3Handle h $ S3.putBucketVersioning b S3.VersioningEnabled
+#else
+		showLongNote $ unlines
+			[ "This version of git-annex cannot auto-enable S3 bucket versioning."
+			, "You need to manually enable versioning in the S3 console"
+			, "for the bucket \"" ++ T.unpack b ++ "\""
+			, "https://docs.aws.amazon.com/AmazonS3/latest/user-guide/enable-versioning.html"
+			, "It's important you enable versioning before storing anything in the bucket!"
+			]
+#endif
+
+-- If the remote has versioning enabled, but the version ID is for some
+-- reason not being recorded, it's not safe to perform an action that
+-- will remove the unversioned file. The file may be the only copy of an
+-- annex object.
+--
+-- This code could be removed eventually, since enableBucketVersioning
+-- will avoid this situation. Before that was added, some remotes
+-- were created without versioning, some unversioned files exported to
+-- them, and then versioning enabled, and this is to avoid data loss in
+-- those cases.
+checkVersioning :: S3Info -> UUID -> Key -> Annex Bool -> Annex Bool
+checkVersioning info u k a
+	| versioning info = getS3VersionID u k >>= \case
+		[] -> do
+			warning $ "Remote is configured to use versioning, but no S3 version ID is recorded for this key, so it cannot safely be modified."
+			return False
+		_ -> a
+	| otherwise = a
