@@ -14,12 +14,13 @@ import RemoteDaemon.Transport.Ssh (transportUsingCmd)
 import Git.GCrypt
 import Remote.Helper.Ssh
 import Remote.GCrypt (accessShellConfig)
+import Annex.Ssh
 
 transport :: Transport
 transport rr@(RemoteRepo r gc) url h@(TransportHandle (LocalRepo g) _) ichan ochan
 	| accessShellConfig gc = do
 		r' <- encryptedRemote g r
-		v <- liftAnnex h $ git_annex_shell r' "notifychanges" [] []
+		v <- liftAnnex h $ git_annex_shell ConsumeStdin r' "notifychanges" [] []
 		case v of
 			Nothing -> noop
 			Just (cmd, params) -> 
