@@ -5,16 +5,12 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
-{-# LANGUAGE CPP #-}
-
 module Types.Messages where
 
 import qualified Utility.Aeson as Aeson
 
 import Control.Concurrent
-#ifdef WITH_CONCURRENTOUTPUT
 import System.Console.Regions (ConsoleRegion)
-#endif
 
 data OutputType = NormalOutput | QuietOutput | JSONOutput JSONOptions
 	deriving (Show)
@@ -40,10 +36,8 @@ data MessageState = MessageState
 	, concurrentOutputEnabled :: Bool
 	, sideActionBlock :: SideActionBlock
 	, implicitMessages :: Bool
-#ifdef WITH_CONCURRENTOUTPUT
 	, consoleRegion :: Maybe ConsoleRegion
 	, consoleRegionErrFlag :: Bool
-#endif
 	, jsonBuffer :: Maybe Aeson.Object
 	, promptLock :: MVar () -- left full when not prompting
 	}
@@ -56,10 +50,8 @@ newMessageState = do
 		, concurrentOutputEnabled = False
 		, sideActionBlock = NoBlock
 		, implicitMessages = True 
-#ifdef WITH_CONCURRENTOUTPUT
 		, consoleRegion = Nothing
 		, consoleRegionErrFlag = False
-#endif
 		, jsonBuffer = Nothing
 		, promptLock = promptlock
 		}
