@@ -5,6 +5,8 @@
  - Licensed under the GNU GPL version 3 or higher.
  -}
 
+{-# LANGUAGE FlexibleInstances #-}
+
 module Types.TrustLevel (
 	TrustLevel(..),
 	TrustMap,
@@ -15,17 +17,19 @@ module Types.TrustLevel (
 
 import qualified Data.Map as M
 import Data.Default
+import Data.Ord
 
 import Types.UUID
 
--- This order may seem backwards, but we generally want to list dead
--- remotes last and trusted ones first.
-data TrustLevel = Trusted | SemiTrusted | UnTrusted | DeadTrusted
+data TrustLevel = DeadTrusted | UnTrusted | SemiTrusted | Trusted
 	deriving (Eq, Enum, Ord, Bounded, Show)
 
 instance Default TrustLevel  where
 	def = SemiTrusted
 
+instance Default (Down TrustLevel)  where
+	def = Down def
+
 type TrustMap = M.Map UUID TrustLevel
 
 readTrustLevel :: String -> Maybe TrustLevel
