@@ -29,6 +29,7 @@ module Utility.Url (
 	getUrlInfo,
 	assumeUrlExists,
 	download,
+	downloadQuiet,
 	sinkResponseFile,
 	downloadPartial,
 	parseURIRelaxed,
@@ -51,6 +52,7 @@ import Control.Monad.Trans.Resource
 import Network.HTTP.Conduit
 import Network.HTTP.Client
 import Data.Conduit
+import System.Log.Logger
 
 #if ! MIN_VERSION_http_client(0,5,0)
 responseTimeoutNone :: Maybe Int
@@ -138,19 +140,21 @@ curlParams uo ps = ps ++ uaparams ++ headerparams ++ addedparams ++ schemeparams
 		]
 	schemelist = map fromScheme $ S.toList $ allowedSchemes uo
 
-checkPolicy :: UrlOptions -> URI -> a -> IO a -> IO a
-checkPolicy uo u onerr a
+checkPolicy :: UrlOptions -> URI -> a -> (String -> IO b) -> IO a -> IO a
+checkPolicy uo u onerr displayerror a
 	| allowedScheme uo u = a
 	| otherwise = do
-		hPutStrLn stderr $ 
+		void $ displayerror $
 			"Configuration does not allow accessing " ++ show u
-		hFlush stderr
 		return onerr
 
-unsupportedUrlScheme :: URI -> IO ()
-unsupportedUrlScheme u = do
-	hPutStrLn stderr $ 
-		"Unsupported url scheme" ++ show u
+unsupportedUrlScheme :: URI -> (String -> IO a) -> IO a
+unsupportedUrlScheme u displayerror =
+	displayerror $ "Unsupported url scheme " ++ show u
+
+warnError :: String -> IO ()
+warnError msg = do
+	hPutStrLn stderr msg
 	hFlush stderr
 
 allowedScheme :: UrlOptions -> URI -> Bool
@@ -191,15 +195,15 @@ assumeUrlExists = UrlInfo True Nothing Nothing
  - also returning its size and suggested filename if available. -}
 getUrlInfo :: URLString -> UrlOptions -> IO UrlInfo
 getUrlInfo url uo = case parseURIRelaxed url of
-	Just u -> checkPolicy uo u dne $
-		case (urlDownloader uo, parseUrlConduit (show u)) of
+	Just u -> checkPolicy uo u dne warnError $
+		case (urlDownloader uo, parseUrlRequest (show u)) of
 			(DownloadWithConduit, Just req) ->
 				existsconduit req
 					`catchNonAsync` (const $ return dne)
 			(DownloadWithConduit, Nothing)
 				| isfileurl u -> existsfile u
 				| otherwise -> do
-					unsupportedUrlScheme u
+					unsupportedUrlScheme u warnError
 					return dne
 			(DownloadWithCurl _, _) 
 				| isfileurl u -> existsfile u
@@ -232,6 +236,7 @@ getUrlInfo url uo = case parseURIRelaxed url of
 
 	existsconduit req = do
 		let req' = headRequest (applyRequest uo req)
+		debugM "url" (show req')
 		runResourceT $ do
 			resp <- http req' (httpManager uo)
 			-- forces processing the response while
@@ -273,8 +278,7 @@ getUrlInfo url uo = case parseURIRelaxed url of
 contentDispositionFilename :: String -> Maybe FilePath
 contentDispositionFilename s
 	| "attachment; filename=\"" `isPrefixOf` s && "\"" `isSuffixOf` s =
-		Just $ reverse $ drop 1 $ reverse $ 
-			drop 1 $ dropWhile (/= '"') s
+		Just $ dropFromEnd 1 $ drop 1 $ dropWhile (/= '"') s
 	| otherwise = Nothing
 
 headRequest :: Request -> Request
@@ -292,38 +296,46 @@ headRequest r = r
  - Displays error message on stderr when download failed.
  -}
 download :: MeterUpdate -> URLString -> FilePath -> UrlOptions -> IO Bool
-download meterupdate url file uo =
+download = download' False
+
+{- Avoids displaying any error message. -}
+downloadQuiet :: MeterUpdate -> URLString -> FilePath -> UrlOptions -> IO Bool
+downloadQuiet = download' True
+
+download' :: Bool -> MeterUpdate -> URLString -> FilePath -> UrlOptions -> IO Bool
+download' noerror meterupdate url file uo =
 	catchJust matchHttpException go showhttpexception
-		`catchNonAsync` showerr
+		`catchNonAsync` (dlfailed . show)
   where
 	go = case parseURIRelaxed url of
-		Just u -> checkPolicy uo u False $
-			case (urlDownloader uo, parseUrlConduit (show u)) of
+		Just u -> checkPolicy uo u False dlfailed $
+			case (urlDownloader uo, parseUrlRequest (show u)) of
 				(DownloadWithConduit, Just req) ->
 					downloadconduit req
 				(DownloadWithConduit, Nothing)
 					| isfileurl u -> downloadfile u
-					| otherwise -> do
-						unsupportedUrlScheme u
-						return False
+					| otherwise -> unsupportedUrlScheme u dlfailed
 				(DownloadWithCurl _, _)
 					| isfileurl u -> downloadfile u
 					| otherwise -> downloadcurl
-		Nothing -> return False
+		Nothing -> do
+			liftIO $ debugM "url" url
+			dlfailed "invalid url"
 	
 	isfileurl u = uriScheme u == "file:"
 
 	downloadconduit req = catchMaybeIO (getFileSize file) >>= \case
 		Nothing -> runResourceT $ do
-			resp <- http (applyRequest uo req') (httpManager uo)
+			liftIO $ debugM "url" (show req')
+			resp <- http req' (httpManager uo)
 			if responseStatus resp == ok200
 				then store zeroBytesProcessed WriteMode resp
 				else showrespfailure resp
 		Just sz -> resumeconduit req' sz
 	  where
-		-- Override http-client's default decompression of gzip
-		-- compressed files. We want the unmodified file content.
-		req' = req
+		req' = applyRequest uo $ req
+			-- Override http-client's default decompression of gzip
+			-- compressed files. We want the unmodified file content.
 			{ requestHeaders = (hAcceptEncoding, "identity") :
 				filter ((/= hAcceptEncoding) . fst)
 					(requestHeaders req)
@@ -335,7 +347,14 @@ download meterupdate url file uo =
 			-- This could be improved by fixing
 			-- https://github.com/aristidb/http-types/issues/87
 			Just crh -> crh == B8.fromString ("bytes */" ++ show sz)
-			Nothing -> False
+			-- Some http servers send no Content-Range header when
+			-- the range extends beyond the end of the file.
+			-- There is no way to distinguish between the file
+			-- being the same size on the http server, vs
+			-- it being shorter than the file we already have.
+			-- So assume we have the whole content of the file
+			-- already, the same as wget and curl do.
+			Nothing -> True
 
 	-- Resume download from where a previous download was interrupted, 
 	-- when supported by the http server. The server may also opt to
@@ -347,6 +366,7 @@ download meterupdate url file uo =
 	  where
 		dl = runResourceT $ do
 			let req' = req { requestHeaders = resumeFromHeader sz : requestHeaders req }
+			liftIO $ debugM "url" (show req')
 			resp <- http req' (httpManager uo)
 			if responseStatus resp == partialContent206
 				then store (BytesProcessed sz) AppendMode resp
@@ -354,11 +374,8 @@ download meterupdate url file uo =
 					then store zeroBytesProcessed WriteMode resp
 					else showrespfailure resp
 	
-	showrespfailure resp = liftIO $ do
-		hPutStrLn stderr $ B8.toString $
-			statusMessage $ responseStatus resp
-		hFlush stderr
-		return False
+	showrespfailure = liftIO . dlfailed . B8.toString 
+		. statusMessage . responseStatus
 	showhttpexception he = do
 #if MIN_VERSION_http_client(0,5,0)
 		let msg = case he of
@@ -376,13 +393,13 @@ download meterupdate url file uo =
 				B8.toString (statusMessage status)
 			_ -> show he
 #endif
-		hPutStrLn stderr $ "download failed: " ++ msg
-		hFlush stderr
-		return False
-	showerr e = do
-		hPutStrLn stderr (show e)
-		hFlush stderr
-		return False
+		dlfailed msg
+	dlfailed msg
+		| noerror = return False
+		| otherwise = do
+			hPutStrLn stderr $ "download failed: " ++ msg
+			hFlush stderr
+			return False
 	
 	store initialp mode resp = do
 		sinkResponseFile meterupdate initialp file mode resp
@@ -394,13 +411,15 @@ download meterupdate url file uo =
 		unlessM (doesFileExist file) $
 			writeFile file ""
 		let ps = curlParams uo
-			[ Param "-sS"
+			[ if noerror
+				then Param "-S"
+				else Param "-sS"
 			, Param "-f"
 			, Param "-L"
 			, Param "-C", Param "-"
 			]
 		boolSystem "curl" (ps ++ [Param "-o", File file, File url])
-					
+	
 	downloadfile u = do
 		let src = unEscapeString (uriPath u)
 		withMeteredFile src meterupdate $
@@ -448,35 +467,23 @@ downloadPartial url uo n = case parseURIRelaxed url of
 	Nothing -> return Nothing
 	Just u -> go u `catchNonAsync` const (return Nothing)
   where
-	go u = case parseUrlConduit (show u) of
+	go u = case parseUrlRequest (show u) of
 		Nothing -> return Nothing
 		Just req -> do
 			let req' = applyRequest uo req
+			liftIO $ debugM "url" (show req')
 			withResponse req' (httpManager uo) $ \resp ->
 				if responseStatus resp == ok200
-					then Just <$> brread n [] (responseBody resp)
+					then Just <$> brReadSome (responseBody resp) n
 					else return Nothing
 
-	-- could use brReadSome here, needs newer http-client dependency
-	brread n' l rb
-		| n' <= 0 = return (L.fromChunks (reverse l))
-		| otherwise = do
-			bs <- brRead rb
-			if B.null bs
-				then return (L.fromChunks (reverse l))
-				else brread (n' - B.length bs) (bs:l) rb
-
 {- Allows for spaces and other stuff in urls, properly escaping them. -}
 parseURIRelaxed :: URLString -> Maybe URI
 parseURIRelaxed s = maybe (parseURIRelaxed' s) Just $
 	parseURI $ escapeURIString isAllowedInURI s
 
-parseUrlConduit :: URLString -> Maybe Request
-#if MIN_VERSION_http_client(0,4,30)
-parseUrlConduit = parseUrlThrow
-#else
-parseUrlConduit = parseUrl
-#endif
+parseUrlRequest :: URLString -> Maybe Request
+parseUrlRequest = parseUrlThrow
 
 {- Some characters like '[' are allowed in eg, the address of
  - an uri, but cannot appear unescaped further along in the uri.
