@@ -1,7 +1,6 @@
 {- Yesod stuff, that's typically found in the scaffolded site.
  -
- - Also a bit of a compatability layer to make it easier to support yesod
- - 1.1-1.4 in the same code base.
+ - Also a bit of a compatability layer for older versions of yesod.
  -
  - Copyright 2012-2014 Joey Hess <id@joeyh.name>
  -
@@ -13,28 +12,17 @@
 module Utility.Yesod 
 	( module Y
 	, liftH
-#ifndef __NO_TH__
 	, widgetFile
 	, hamletTemplate
-#endif
-#if ! MIN_VERSION_yesod_core(1,2,20)
-	, withUrlRenderer
-#endif
 	) where
 
 import Yesod as Y
 import Yesod.Form.Bootstrap3 as Y hiding (bfs)
-#ifndef __NO_TH__
 import Yesod.Default.Util
 import Language.Haskell.TH.Syntax (Q, Exp)
 import Data.Default (def)
 import Text.Hamlet hiding (Html)
-#endif
-#if ! MIN_VERSION_yesod(1,4,0)
-import Data.Text (Text)
-#endif
 
-#ifndef __NO_TH__
 widgetFile :: String -> Q Exp
 widgetFile = widgetFileNoReload $ def
 	{ wfsHamletSettings = defaultHamletSettings
@@ -44,7 +32,6 @@ widgetFile = widgetFileNoReload $ def
 
 hamletTemplate :: FilePath -> FilePath
 hamletTemplate f = globFile "hamlet" f
-#endif
 
 {- Lift Handler to Widget -}
 #if MIN_VERSION_yesod_core(1,6,0)
@@ -53,8 +40,3 @@ liftH :: HandlerFor site a -> WidgetFor site a
 liftH :: Monad m => HandlerT site m a -> WidgetT site m a
 #endif
 liftH = handlerToWidget
-
-#if ! MIN_VERSION_yesod_core(1,2,20)
-withUrlRenderer :: MonadHandler m => ((Route (HandlerSite m) -> [(Text, Text)] -> Text) -> output) -> m output
-withUrlRenderer = giveUrlRenderer
-#endif
